# Generated by roxygen2: do not edit by hand

S3method(print,maxent_sample)
export(clamp_grids)
export(compute_mess)
export(compute_mess_range)
export(compute_percent_contribution)
export(compute_permutation_importance)
export(compute_response_curve)
export(compute_response_curve_fixed)
export(compute_variable_ranges)
export(coords_to_rowcol)
export(create_grid_dimension)
export(create_grid_float)
export(create_hinge_feature)
export(create_layer)
export(create_linear_feature)
export(create_product_feature)
export(create_quadratic_feature)
export(create_sample)
export(create_threshold_feature)
export(csv_close)
export(csv_headers)
export(csv_next_record)
export(csv_open)
export(csv_read_double_column)
export(csv_writer_close)
export(csv_writer_open)
export(csv_writer_print)
export(csv_writer_print_double)
export(csv_writer_println)
export(eval_auc)
export(eval_correlation)
export(eval_logloss)
export(eval_misclassification)
export(eval_model)
export(eval_square_error)
export(extract_predictions_raw)
export(feature_eval)
export(feature_get_info)
export(generate_features)
export(get_grid_dimension_info)
export(get_layer_info)
export(get_sample_info)
export(grid_float_from_matrix)
export(grid_float_info)
export(grid_float_to_matrix)
export(grid_from_matrix)
export(grid_get_value)
export(grid_get_values_batch)
export(grid_has_data)
export(grid_read_asc)
export(grid_read_file)
export(grid_set_value)
export(grid_to_matrix)
export(grid_write_asc)
export(layer_name_from_path)
export(maxent_append_results_csv)
export(maxent_auc)
export(maxent_background_indices)
export(maxent_clamp)
export(maxent_color_ramp)
export(maxent_correlation)
export(maxent_csv_close)
export(maxent_csv_headers)
export(maxent_csv_next)
export(maxent_csv_open)
export(maxent_csv_read_column)
export(maxent_csv_write)
export(maxent_csv_write_close)
export(maxent_csv_write_num)
export(maxent_csv_write_open)
export(maxent_csv_write_row)
export(maxent_dimension)
export(maxent_evaluate)
export(maxent_extract_lambdas)
export(maxent_extract_occurrence_env_terra)
export(maxent_extract_predictions_cloglog)
export(maxent_extract_predictions_logistic)
export(maxent_extract_predictions_raw)
export(maxent_feature_eval)
export(maxent_feature_info)
export(maxent_featured_space)
export(maxent_featured_space_create)
export(maxent_featured_space_from_callback)
export(maxent_featured_space_from_rast)
export(maxent_featured_space_info)
export(maxent_fit)
export(maxent_generate_features)
export(maxent_get_entropy)
export(maxent_get_loss)
export(maxent_get_weights)
export(maxent_grid)
export(maxent_grid_from_matrix)
export(maxent_grid_from_terra)
export(maxent_grid_info)
export(maxent_grid_to_matrix)
export(maxent_grid_to_terra)
export(maxent_hinge_feature)
export(maxent_layer)
export(maxent_layer_info)
export(maxent_layer_name)
export(maxent_linear_feature)
export(maxent_load_lambdas)
export(maxent_logloss)
export(maxent_mess)
export(maxent_mess_range)
export(maxent_misclassification)
export(maxent_model_entropy)
export(maxent_model_loss)
export(maxent_model_weights)
export(maxent_percent_contribution)
export(maxent_permutation_importance)
export(maxent_plot_response_curves)
export(maxent_plot_variable_importance)
export(maxent_predict)
export(maxent_predict_model)
export(maxent_print_results)
export(maxent_product_feature)
export(maxent_project_cloglog)
export(maxent_project_logistic)
export(maxent_project_raw)
export(maxent_quadratic_feature)
export(maxent_raster_sample_indices)
export(maxent_read_asc)
export(maxent_read_grid)
export(maxent_read_lambdas)
export(maxent_read_occurrences)
export(maxent_response_curve)
export(maxent_response_curve_fixed)
export(maxent_run)
export(maxent_sample)
export(maxent_save_lambdas)
export(maxent_sequential_fit)
export(maxent_set_sample_expectations)
export(maxent_space_info)
export(maxent_square_error)
export(maxent_threshold_feature)
export(maxent_train)
export(maxent_train_terra)
export(maxent_variable_ranges)
export(maxent_write_asc)
export(maxent_write_lambdas)
export(maxent_write_omission_csv)
export(maxent_write_prediction_png)
export(maxent_write_sample_predictions)
export(project_cloglog)
export(project_logistic)
export(project_raw)
export(sample_get_feature)
export(sample_set_feature)
importFrom(Rcpp,sourceCpp)
importFrom(methods,slot)
importFrom(methods,slotNames)
useDynLib(maxentcpp, .registration = TRUE)
