% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid_io.R
\name{maxent_csv_read_column}
\alias{maxent_csv_read_column}
\title{Read an Entire Column as Doubles}
\usage{
maxent_csv_read_column(reader, field)
}
\arguments{
\item{reader}{External pointer to a CsvReader object.}

\item{field}{Character: column name.}
}
\value{
Numeric vector.
}
\description{
Reads from the current file position to EOF.
}
