% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{compute_percent_contribution}
\alias{compute_percent_contribution}
\title{Compute Percent Contribution}
\usage{
compute_percent_contribution(fs_ptr, feature_names)
}
\arguments{
\item{fs_ptr}{External pointer to a FeaturedSpace object.}

\item{feature_names}{Character vector of base variable names.}
}
\value{
A data.frame with columns: name, contribution.
}
\description{
Computes variable contribution based on sum of absolute lambda values
for features derived from each variable.
}
