% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{grid_has_data}
\alias{grid_has_data}
\title{Check if grid cell has data}
\usage{
grid_has_data(grid_ptr, row, col)
}
\arguments{
\item{grid_ptr}{External pointer to Grid}

\item{row}{Row index}

\item{col}{Column index}
}
\value{
TRUE if cell has valid data
}
\description{
Check if grid cell has data
}
