% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid_io.R
\name{maxent_grid_to_matrix}
\alias{maxent_grid_to_matrix}
\title{Convert Grid to R Matrix}
\usage{
maxent_grid_to_matrix(grid)
}
\arguments{
\item{grid}{External pointer to a GridFloat object.}
}
\value{
Numeric matrix (\code{nrows} \eqn{\times} \code{ncols}).
}
\description{
Extracts the data from a GridFloat as an R numeric matrix.
NODATA cells are converted to \code{NA}.
}
