% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/maxent.R
\name{maxent_sample}
\alias{maxent_sample}
\title{Create a MaxEnt Sample Object}
\usage{
maxent_sample(lon, lat, name = "", dim = NULL)
}
\arguments{
\item{lon}{Longitude coordinate}

\item{lat}{Latitude coordinate}

\item{name}{Sample identifier/name}

\item{dim}{Optional GridDimension object to calculate row/col indices}
}
\value{
Sample object (external pointer)
}
\description{
Creates a sample point representing a species occurrence location.
}
\examples{
sample <- maxent_sample(lon = -118.5, lat = 36.5, name = "site1")
}
