% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/features.R
\name{maxent_product_feature}
\alias{maxent_product_feature}
\title{Create a Product Feature}
\usage{
maxent_product_feature(
  values1,
  values2,
  name,
  min1 = NULL,
  max1 = NULL,
  min2 = NULL,
  max2 = NULL
)
}
\arguments{
\item{values1}{Numeric vector for the first environmental variable.}

\item{values2}{Numeric vector for the second environmental variable
(must have the same length as \code{values1}).}

\item{name}{Character string: feature name/identifier.}

\item{min1}{Minimum of the first variable. If \code{NULL} (default),
computed as \code{min(values1)}.}

\item{max1}{Maximum of the first variable. If \code{NULL} (default),
computed as \code{max(values1)}.}

\item{min2}{Minimum of the second variable. If \code{NULL} (default),
computed as \code{min(values2)}.}

\item{max2}{Maximum of the second variable. If \code{NULL} (default),
computed as \code{max(values2)}.}
}
\value{
External pointer to a ProductFeature C++ object.
}
\description{
Creates an interaction feature between two environmental variables:
\code{eval(i) = norm(values1[i]) * norm(values2[i])}.
}
\examples{
temp <- c(0, 5, 10)
prec <- c(100, 200, 150)
f <- maxent_product_feature(temp, prec, "temp_x_prec")
maxent_feature_eval(f, 2)
}
