% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/model_diagnostics.R
\name{maxent_variable_ranges}
\alias{maxent_variable_ranges}
\title{Compute Variable Ranges from Grids}
\usage{
maxent_variable_ranges(env_grids)
}
\arguments{
\item{env_grids}{List of external pointers to Grid<float> objects.}
}
\value{
A data.frame with columns: min, max (one row per variable).
}
\description{
Scans all valid cells in the grids to determine the [min, max] range
of each environmental variable.
}
