% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{feature_get_info}
\alias{feature_get_info}
\title{Get feature metadata}
\usage{
feature_get_info(feature_ptr)
}
\arguments{
\item{feature_ptr}{External pointer to a Feature object}
}
\value{
Named list with feature properties
}
\description{
Returns a list with name, type, lambda, min, and max values.
}
