% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid_io.R
\name{maxent_csv_write_close}
\alias{maxent_csv_write_close}
\title{Close a CSV Writer}
\usage{
maxent_csv_write_close(writer)
}
\arguments{
\item{writer}{External pointer to a CsvWriter object.}
}
\value{
Invisibly returns \code{NULL}.
}
\description{
Flushes any pending data and closes the CSV file.
}
