% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{maxent_set_streaming_eval}
\alias{maxent_set_streaming_eval}
\title{Enable or disable streaming-eval mode on a FeaturedSpace}
\usage{
maxent_set_streaming_eval(fs_ptr, enabled = TRUE)
}
\arguments{
\item{fs_ptr}{External pointer to a FeaturedSpace object.}

\item{enabled}{Logical flag.}
}
\value{
Called for side effects; returns invisibly.
}
\description{
Enable or disable streaming-eval mode on a FeaturedSpace
}
\keyword{internal}
