% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{create_hinge_feature}
\alias{create_hinge_feature}
\title{Create a HingeFeature object}
\usage{
create_hinge_feature(values, name, min_knot, max_knot, is_reverse = FALSE)
}
\arguments{
\item{values}{Numeric vector of environmental variable values}

\item{name}{Feature name/identifier}

\item{min_knot}{Lower knot of the hinge}

\item{max_knot}{Upper knot of the hinge (must be > min_knot)}

\item{is_reverse}{If TRUE, use reverse hinge; if FALSE (default), use forward hinge}
}
\value{
External pointer to HingeFeature object
}
\description{
Creates a piecewise-linear hinge feature.
Forward hinge: eval(i) = (values[i] > min_knot) ? (values[i] - min_knot) / (max_knot - min_knot) : 0.
Reverse hinge: eval(i) = (values[i] < max_knot) ? (max_knot - values[i]) / (max_knot - min_knot) : 0.
}
