% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/model_evaluation.R
\name{maxent_square_error}
\alias{maxent_square_error}
\title{Compute Mean Squared Error}
\usage{
maxent_square_error(presence, absence)
}
\arguments{
\item{presence}{Numeric vector of prediction scores at presence sites.}

\item{absence}{Numeric vector of prediction scores at absence sites.}
}
\value{
Mean squared error.
}
\description{
Presence sites contribute (1 - pred)^2, absence sites contribute pred^2.
}
\examples{
maxent_square_error(c(1.0, 1.0), c(0.0, 0.0))  # 0.0
}
