% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/featured_space.R
\name{maxent_load_lambdas}
\alias{maxent_load_lambdas}
\title{Load Model Lambdas from File}
\usage{
maxent_load_lambdas(featured_space, file)
}
\arguments{
\item{featured_space}{External pointer to a FeaturedSpace object (must have
features with the same names as those in the file).}

\item{file}{Character: path to the lambdas file.}
}
\value{
Invisibly returns the FeaturedSpace external pointer (updated
  in-place).
}
\description{
Reads model coefficients from a .lambdas file and applies them to
a FeaturedSpace that was created with the same features.
}
\examples{
\donttest{
maxent_load_lambdas(fs, tempfile(fileext = ".lambdas"))
}
}
