% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{csv_next_record}
\alias{csv_next_record}
\title{Read the next CSV record}
\usage{
csv_next_record(reader_ptr)
}
\arguments{
\item{reader_ptr}{External pointer to a CsvReader object.}
}
\value{
Character vector of field values, or NULL on EOF.
}
\description{
Read the next CSV record
}
