% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid_io.R
\name{maxent_csv_next}
\alias{maxent_csv_next}
\title{Read the Next CSV Record}
\usage{
maxent_csv_next(reader)
}
\arguments{
\item{reader}{External pointer to a CsvReader object.}
}
\value{
Character vector of field values, or \code{NULL} on EOF.
}
\description{
Read the Next CSV Record
}
