% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grid_io.R
\name{maxent_csv_write}
\alias{maxent_csv_write}
\title{Write a String Value to the Current CSV Row}
\usage{
maxent_csv_write(writer, column, value)
}
\arguments{
\item{writer}{External pointer to a CsvWriter object.}

\item{column}{Character: column name.}

\item{value}{Character: value to write.}
}
\value{
Invisibly returns the writer object.
}
\description{
Adds a \code{column = value} pair (as a character string) to the current
row buffer. Call \code{\link{maxent_csv_write_row}} to flush the row.
}
