% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{eval_correlation}
\alias{eval_correlation}
\title{Compute Pearson Correlation}
\usage{
eval_correlation(x, y)
}
\arguments{
\item{x}{Numeric vector.}

\item{y}{Numeric vector (same length as x).}
}
\value{
Correlation coefficient in [-1, 1].
}
\description{
Computes Pearson correlation coefficient between two numeric vectors.
}
