% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{create_linear_feature}
\alias{create_linear_feature}
\title{Create a LinearFeature object}
\usage{
create_linear_feature(values, name, min_val, max_val)
}
\arguments{
\item{values}{Numeric vector of environmental variable values}

\item{name}{Feature name/identifier}

\item{min_val}{Minimum value for normalization}

\item{max_val}{Maximum value for normalization}
}
\value{
External pointer to LinearFeature object
}
\description{
Creates a linear (normalized) feature: eval(i) = (values[i] - min) / (max - min).
Returns 0 when min == max.
}
